## Description
Brief description of changes made in this PR.

Fixes #(issue number)

## Type of Change
- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Code refactoring
- [ ] Performance improvement
- [ ] Other (please describe)

## Testing
- [ ] Tests added/updated for new functionality
- [ ] All tests pass locally (`pytest`)
- [ ] Manually tested the changes
- [ ] Tested on multiple Python versions (if applicable)
- [ ] Tested with actual Supernote device (if applicable)

## Documentation
- [ ] Code documentation (docstrings) added/updated
- [ ] README updated (if needed)
- [ ] CHANGELOG.md updated
- [ ] Examples added/updated (if applicable)

## Checklist
- [ ] Code follows project style guidelines (PEP 8)
- [ ] Self-reviewed my own code
- [ ] Commented code in hard-to-understand areas
- [ ] No new warnings introduced
- [ ] Commit messages are clear and descriptive
- [ ] No personal data or credentials in code

## Screenshots (if applicable)
Add screenshots or terminal output to help explain your changes.

## Additional Notes
Any additional information that reviewers should know about this PR.
